==> snips-sam-0.0.21.tgz: package/src/commands/install/assistant.ts <==
import * as yargs from 'yargs'
import { cli } from '../../cli'
import { SSHService, ConsoleClient } from '../../session'
import chalk from 'chalk'
import * as shelljs from 'shelljs'

exports.command = 'assistant'
exports.desc = 'Install an assistant from different locations: console (with or without a project id) or a local file path.'
exports.builder = {
    path: {
        demandOption: false,
        describe: 'Path to local assistant folder, can be a zip',
        type: 'string',
        conflicts: 'id',
        alias: 'p',
    },
    id: {
        demandOption: false,
        describe: 'Your assistant id from the console, format: proj_XXXX',
        type: 'string',
        conflicts: 'path',
        alias: 'i',
    },
}

exports.handler = async (argv: yargs.Argv) => {
    const argsPath: string = JSON.parse(JSON.stringify(argv)).path
    const id: string = JSON.parse(JSON.stringify(argv)).id

    const ssh = new SSHService()
    await ssh.connect()
    .catch(e => {
        cli.stream.error(e)
        process.exit()
    })

    let assistantPath: string

    if (argsPath !== undefined && argsPath.length > 0) {
        assistantPath = argsPath
    } else {
        // The user either provides an id, or we connect to the console so he can choose one
        if (cli.config.user === undefined) {
            throw new Error('No user information to connect to the console, you must login first with ' + chalk.blue('sam login'))
        }
        const client = new ConsoleClient()

        let assistantId: string
        if (id !== undefined && id.length > 0) {
            assistantId = id
        } else {
            try {
                cli.stream.loading('Fetching assistants')
                assistantId = await client.assistantList(cli.config.user.id)
                .then(async assistants => {
                    cli.stream.done()
                    const assistantNames = assistants.map(assistant => assistant.title)
                    if (assistantNames.length === 0) throw new Error('No assistants found on your account.')
                    if (assistantNames.length === 1) {
                        cli.stream.println('Found 1 assistant named ' + assistant[0].title)
                        return assistants[0].id
                    }

                    return await cli.prompt.promptList('assistant', 'Choose the assistant you wish to install on the device', assistantNames)
                    .then(response => {
                        const assistantSelected = assistants.find(value => value.title === response['assistant'])
                        if (assistantSelected === undefined) throw new Error('No assistant choosen')
                        return assistantSelected.id
                    })
                })
            } catch (e) {
                cli.stream.error('Error fetching the assistant, reason: ' + e.message)
                process.exit(0)
                return
            }
        }

        cli.stream.println('Downloading assistant')
        assistantPath = await client.downloadAssistant(
            assistantId,
            steps => {
                cli.stream.done()
                cli.stream.loading(steps)
            },
            false, true)
    }

    cli.stream.loading(`Deploying assistant to ${ssh.credentials.hostname}...`)
    await ssh.installAssistant(assistantPath)
    .then(_ => shelljs.exec(`rm ${assistantPath}`, { async: false, silent: false }))
    .then(_ => cli.stream.success())
    .catch(e => {
        cli.stream.error('Unable to install the assistant: ' + e.message)
        ssh.disconnect()
        process.exit()
    })

    await ssh.getSnippets()
    .then(snippets => {
        const skillCount = Array.from(snippets.keys()).length
        if (skillCount > 0) {
            cli.stream.success('Found 1 skill with the assistant')
        } else {
            cli.stream.success(`Found ${skillCount} skills with the assistant`)
        }
        cli.stream.hint('You can install your skills by running ' + chalk.blue('sam install skills'))
    })
    .catch(_ => {}) // We ignore the error since it's only meant to be informative

    const assistant = await ssh.getInstalledAssistant()
    if (assistant !== undefined) {
        cli.stream.success(`Snips assistant is now running. Say ${chalk.blue(assistant.hotword)} to start!`)
    } else {
        cli.stream.success(`Snips assistant is now running`)
    }
    cli.stream.hint(`Run ${chalk.blue('sam watch')} to see the logs`)

    ssh.disconnect()
    process.exit()
}

==> snips-sam-0.0.23.tgz: package/src/commands/install/assistant.ts <==
import * as yargs from 'yargs'
import { cli } from '../../cli'
import { SSHService, ConsoleClient } from '../../session'
import chalk from 'chalk'
import * as shelljs from 'shelljs'

exports.command = 'assistant'
exports.desc = 'Install an assistant from different locations: console (with or without a project id) or a local file path.'
exports.builder = {
    path: {
        demandOption: false,
        describe: 'Path to local assistant folder, can be a zip',
        type: 'string',
        conflicts: 'id',
        alias: 'p',
    },
    id: {
        demandOption: false,
        describe: 'Your assistant id from the console, format: proj_XXXX',
        type: 'string',
        conflicts: 'path',
        alias: 'i',
    },
}

exports.handler = async (argv: yargs.Argv) => {
    const argsPath: string = JSON.parse(JSON.stringify(argv)).path
    const id: string = JSON.parse(JSON.stringify(argv)).id

    const ssh = new SSHService()
    await ssh.connect()
    .catch(e => {
        cli.stream.error(e)
        process.exit()
    })

    let assistantPath: string

    if (argsPath !== undefined && argsPath.length > 0) {
        assistantPath = argsPath
    } else {
        // The user either provides an id, or we connect to the console so he can choose one
        if (cli.config.user === undefined) {
            throw new Error('No user information to connect to the console, you must login first with ' + chalk.blue('sam login'))
        }
        const client = new ConsoleClient()

        let assistantId: string
        if (id !== undefined && id.length > 0) {
            assistantId = id
        } else {
            try {
                cli.stream.loading('Fetching assistants')
                assistantId = await client.assistantList(cli.config.user.id)
                .then(async assistants => {
                    cli.stream.done()
                    const assistantNames = assistants.map(assistant => assistant.title)
                    if (assistantNames.length === 0) throw new Error('No assistants found on your account.')
                    if (assistantNames.length === 1) {
                        cli.stream.println('Found 1 assistant named ' + assistant[0].title)
                        return assistants[0].id
                    }

                    return await cli.prompt.promptList('assistant', 'Choose the assistant you wish to install on the device', assistantNames)
                    .then(response => {
                        const assistantSelected = assistants.find(value => value.title === response['assistant'])
                        if (assistantSelected === undefined) throw new Error('No assistant choosen')
                        return assistantSelected.id
                    })
                })
            } catch (e) {
                cli.stream.error('Error fetching the assistant, reason: ' + e.message)
                process.exit(0)
                return
            }
        }

        cli.stream.println('Downloading assistant')
        assistantPath = await client.downloadAssistant(
            assistantId,
            steps => {
                cli.stream.done()
                cli.stream.loading(steps)
            },
            false, true)
    }

    cli.stream.loading(`Deploying assistant to ${ssh.credentials.hostname}...`)
    await ssh.installAssistant(assistantPath)
    .then(_ => shelljs.rm(assistantPath))
    .then(_ => cli.stream.success())
    .catch(e => {
        cli.stream.error('Unable to install the assistant: ' + e.message)
        ssh.disconnect()
        process.exit()
    })

    await ssh.getSnippets()
    .then(snippets => {
        const skillCount = Array.from(snippets.keys()).length
        if (skillCount > 0) {
            cli.stream.success('Found 1 skill with the assistant')
        } else {
            cli.stream.success(`Found ${skillCount} skills with the assistant`)
        }
        cli.stream.hint('You can install your skills by running ' + chalk.blue('sam install skills'))
    })
    .catch(_ => {}) // We ignore the error since it's only meant to be informative

    await ssh.relaunchServices().catch(_ => {})

    const assistant = await ssh.getInstalledAssistant()
    if (assistant !== undefined) {
        cli.stream.success(`Snips assistant is now running. Say ${chalk.blue(assistant.hotword)} to start!`)
    } else {
        cli.stream.success(`Snips assistant is now running`)
    }
    cli.stream.hint(`Run ${chalk.blue('sam watch')} to see the logs`)

    ssh.disconnect()
    process.exit()
}
